==> libbsd_0.6.0.orig.tar.xz: libbsd-0.6.0/test/proctitle.c <==
/*
 * Copyright © 2012-2013 Guillem Jover <guillem@hadrons.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/types.h>
#include <assert.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>

int
main(int argc, char **argv)
{
	const char newtitle_base[] = "test arg1 arg2";
	char *newtitle_full;
	char *envvar;

	setproctitle("-test %s arg2", "arg1");
	assert(strcmp(argv[0], newtitle_base) == 0);

	asprintf(&newtitle_full, "%s: %s", getprogname(), newtitle_base);
	setproctitle("test %s arg2", "arg1");
	assert(strcmp(argv[0], newtitle_full) == 0);
	free(newtitle_full);

	assert(setenv("LIBBSD_TEST", "test value", 1) == 0);
	envvar = getenv("LIBBSD_TEST");
	assert(envvar != NULL);
	assert(strcmp(envvar, "test value") == 0);

	return 0;
}

==> libbsd_0.7.0.orig.tar.xz: libbsd-0.7.0/test/proctitle.c <==
/*
 * Copyright © 2012-2013 Guillem Jover <guillem@hadrons.org>
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL
 * THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <sys/types.h>
#include <assert.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>

int
main(int argc, char **argv, char **envp)
{
	const char newtitle_base[] = "test arg1 arg2";
	char *newtitle_full;
	char *envvar;

#ifdef TEST_USE_SETPROCTITLE_INIT
	setproctitle_init(argc, argv, envp);
#endif

	setproctitle("-test %s arg2", "arg1");
	assert(strcmp(argv[0], newtitle_base) == 0);

	asprintf(&newtitle_full, "%s: %s", getprogname(), newtitle_base);
	setproctitle("test %s arg2", "arg1");
	assert(strcmp(argv[0], newtitle_full) == 0);
	free(newtitle_full);

	assert(setenv("LIBBSD_TEST", "test value", 1) == 0);
	envvar = getenv("LIBBSD_TEST");
	assert(envvar != NULL);
	assert(strcmp(envvar, "test value") == 0);

	return 0;
}
